@@ -295,6 +295,8 @@ insteadof = {
 def pull_or_clone(base_branch, target_path):
     """Make target_path match base_branch, either by pulling or by cloning."""
     base_branch.path = target_path
+    if os.path.exists(target_path) and not os.listdir(target_path):
+        os.rmdir(target_path)
     if not os.path.exists(target_path):
         os.makedirs(target_path)
         base_branch.git_call("init")
