@@ -543,7 +543,7 @@ class BuildTreeTests(GitTestCase):
         source = GitRepository("source")
         source.commit("one")
         # We just create the target as a directory
-        os.mkdir("target")
+        os.makedirs("target/junk")
         base_branch = BaseRecipeBranch("source", "1", 0.2)
         self.assertRaises(
             TargetAlreadyExists, build_tree, base_branch, "target")
@@ -867,6 +867,30 @@ class BuildTreeTests(GitTestCase):
         self.assertEqual(first_commit, target.rev_parse("one"))
         self.assertEqual(["?? b"], target.status())
 
+    def test_pull_or_clone_branch_target_is_empty_dir(self):
+        source = GitRepository("source")
+        source.build_tree(["a"])
+        source.add(["a"])
+        commit = source.commit("one")
+        source.tag("one", commit)
+        base_branch = BaseRecipeBranch("source", "1", 0.2, revspec=commit)
+        os.mkdir("target")
+        pull_or_clone(base_branch, "target")
+        target = GitRepository("target", allow_create=False)
+        self.assertEqual(commit, target.last_revision())
+        self.assertEqual(commit, target.rev_parse("one"))
+
+    def test_pull_or_clone_branch_target_is_nonempty_dir(self):
+        source = GitRepository("source")
+        source.build_tree(["a"])
+        source.add(["a"])
+        commit = source.commit("one")
+        source.tag("one", commit)
+        base_branch = BaseRecipeBranch("source", "1", 0.2, revspec=commit)
+        os.makedirs("target/junk")
+        self.assertRaises(
+            TargetAlreadyExists, pull_or_clone, base_branch, "target")
+
     def test_build_tree_runs_commands(self):
         source = GitRepository("source")
         commit = source.commit("one")
